pub struct MenuSetting {
pub wrapping: bool,
pub scope: bool,
}Expand description
A menu that isolate children Focusables from other focusables
and specify navigation method within itself.
Usage
A MenuSetting can be used to:
- Prevent navigation from one specific submenu to another
- Specify if 2d navigation wraps around the screen,
see
MenuSetting::wrapping. - Specify “scope menus” such that sending a
NavRequest::ScopeMovewhen the focused element is aFocusablenested within thisMenuSettingwill move cursor within this menu. SeeMenuSetting::scope. - Specify submenus and specify from where those submenus are reachable.
- Specify which entity will be the parents of this
MenuSetting. SeeMenuBuilder.
If you want to specify which Focusable should be focused first
when entering a menu,
you should mark one of the children of this menu with Focusable::prioritized.
Limitations
Menu navigation relies heavily on the bevy hierarchy being consistent. You might get inconsistent state under the folowing conditions:
- You despawned an entity in the
FocusState::Activestate - You changed the parent of a
Focusablemember of a menu to a new menu.
The navigation system might still work as expected,
however, Focusable::state may be missleading
for the length of one frame.
Panics
Menu loops will cause a panic. A menu loop is a way to go from menu A to menu B and then from menu B to menu A while never going back.
Don’t worry though, menu loops are really hard to make by accident,
and it will only panic if you use a NavRequest::FocusOn(entity)
where entity is inside a menu loop.
Fields
wrapping: boolWhether to wrap navigation.
When the player moves to a direction where there aren’t any focusables, if this is true, the focus will “wrap” to the other direction of the screen.
scope: boolWhether this is a scope menu.
A scope menu is controlled with NavRequest::ScopeMove
even when the focused element is not in this menu, but in a submenu
reachable from this one.
Implementations
Sourceimpl MenuSetting
impl MenuSetting
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new non-wrapping, non-scopped MenuSetting,
those are the default values.
To create a wrapping/scopped menu, you can use:
MenuSetting::new().wrapping().scope().